# A (very) minimal API client for Grist

Currently only supports a few document operations, but enough for my purposes.

Alternative to the [official API
package](https://github.com/gristlabs/py_grist_api/), which (still)
monkeypatches the standard library for Py3 compatibility.
